" Vim syntax file (spin2.vim)
" Language:	Parallax Propeller P2 Spin2/PASM2
" Maintainer:   Francis Bauer <fbaue00@gmail.com> 2021 Feb
" Last Change:	2025 Jan 15 (For Spin2/PASM2 2025.01.06)
" Leveraged from 'spin.vim' Andrey Demenev <demenev@gmail.com> 2009 Dec 13

" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
if version < 600
  syntax clear
elseif exists("b:current_syntax")
  finish
endif

syn case ignore

syn match spin2LocalLabel	":[a-z_][a-z0-9_]*"
syn match spin2Identifier	"[a-z_][a-z0-9_]*"

" Spin2 Blocks
syn keyword spin2Block CON
syn keyword spin2Block OBJ
syn keyword spin2Block VAR
syn keyword spin2Block PUB
syn keyword spin2Block PRI
syn keyword spin2Block DAT

" Spin2 Download constants
syn keyword spin2Downld DOWNLOAD_BAUD

" Spin2 Pre-Processor commands
setlocal iskeyword+=#
syn keyword spin2PreProc   #DEFINE
syn keyword spin2PreProc   #UNDEF
syn keyword spin2PreCondit #IFDEF
syn keyword spin2PreCondit #IFNDEF
syn keyword spin2PreCondit #ELSEIFDEF
syn keyword spin2PreCondit #ELSEIFNDEF
syn keyword spin2PreCondit #ELSE
syn keyword spin2PreCondit #ENDIF
syn keyword spin2PreProc   __DEBUG__

" Spin2 Task commands
syn keyword spin2Task TASKSPIN
syn keyword spin2Task TASKNEXT
syn keyword spin2Task TASKSTOP
syn keyword spin2Task TASKHALT
syn keyword spin2Task TASKCONT
syn keyword spin2Task TASKCHK
syn keyword spin2Task TASKID
syn keyword spin2Task NEWTASK
syn keyword spin2Task THISTASK
syn keyword spin2Task TASKHLT

" Spin2 Structures
syn keyword spin2Struct STRUCT
syn keyword spin2Struct SIZEOF

" Spin2 Clock modes
syn keyword spin2Clock _CLKFREQ
syn keyword spin2Clock CLKFREQ
syn keyword spin2Clock _CLKMODE
syn keyword spin2Clock CLKMODE
syn keyword spin2Clock CLKSET

" Spin2 word sizes
syn keyword spin2Type BYTE
syn keyword spin2Type LONG
syn keyword spin2Type WORD
syn keyword spin2Type FVAR
syn keyword spin2Type FVARS

" Spin2 Hub variables
syn keyword spin2HubVar VARBASE

" Spin2 Conditionals
syn keyword spin2Cond IF ELSE ELSEIF ELSEIFNOT IFNOT

" Spin2 Flow Control
syn keyword spin2Flow CASE CASE_FAST OTHER
syn keyword spin2Flow ABORT RETURN

" Spin2 Loops
syn keyword spin2Loop REPEAT FROM TO STEP WITH UNTIL WHILE NEXT
syn keyword spin2Loop QUIT

" Spin2/PASM2 Cog registers
syn keyword spin2PASM2Reg REG
syn keyword spin2PASM2Reg PR0 PR1 PR2 PR3 PR4 PR5 PR6 PR7
syn keyword spin2PASM2Reg IJMP3 IRET3 IJMP2 IRET2 IJMP1 IRET1
syn keyword spin2PASM2Reg PA PB PTRA PTRB
syn keyword spin2PASM2Reg DIRA DIRB OUTA OUTB INA INB

" Spin2 Float Operators
syn keyword spin2Float FABS
syn keyword spin2Float FLOAT
syn keyword spin2Float FSQRT
syn keyword spin2Float NAN
syn keyword spin2Float ROUND
syn keyword spin2Float TRUNC

" Spin2 Operators
syn keyword spin2Operator ABS ADDBITS ADDPINS AND
syn keyword spin2Operator BMASK
syn keyword spin2Operator DECOD
syn keyword spin2Operator ENCOD
syn keyword spin2Operator FRAC
syn keyword spin2Operator NOT
syn keyword spin2Operator ONES OR
syn keyword spin2Operator REV ROL ROR
syn keyword spin2Operator SAR SCA SCAS SIGNX SQRT
syn keyword spin2Operator QEXP QLOG
syn keyword spin2Operator XOR
syn keyword spin2Operator ZEROX

" Spin2 Hub Methods
syn keyword spin2Reserved HUBSET
syn keyword spin2Reserved COGSPIN
syn keyword spin2Reserved COGINIT
syn keyword spin2Reserved COGSTOP
syn keyword spin2Reserved COGID
syn keyword spin2Reserved COGCHK
syn keyword spin2Reserved LOCKNEW
syn keyword spin2Reserved LOCKRET
syn keyword spin2Reserved LOCKTRY
syn keyword spin2Reserved LOCKREL
syn keyword spin2Reserved LOCKCHK
syn keyword spin2Reserved COGATN
syn keyword spin2Reserved POLLATN
syn keyword spin2Reserved WAITATN

" Spin2 Pin Methods
syn keyword spin2Reserved PINW PINWRITE
syn keyword spin2Reserved PINL PINLOW
syn keyword spin2Reserved PINH PINHIGH
syn keyword spin2Reserved PINT PINTOGGLE
syn keyword spin2Reserved PINF PINFLOAT
syn keyword spin2Reserved PINR PINREAD
syn keyword spin2Reserved PINSTART
syn keyword spin2Reserved PINCLEAR
syn keyword spin2Reserved WRPIN
syn keyword spin2Reserved WXPIN
syn keyword spin2Reserved WYPIN
syn keyword spin2Reserved AKPIN
syn keyword spin2Reserved RDPIN
syn keyword spin2Reserved RQPIN

" Spin2 Timing Methods
syn keyword spin2Reserved GETCT
syn keyword spin2Reserved POLLCT
syn keyword spin2Reserved WAITCT
syn keyword spin2Reserved WAITUS
syn keyword spin2Reserved WAITMS
syn keyword spin2Reserved GETSEC
syn keyword spin2Reserved GETMS

" Spin2 PASM Interfacing Methods
syn keyword spin2Reserved CALL
syn keyword spin2Reserved REGEXEC
syn keyword spin2Reserved REGLOAD

" Spin2 Math Methods
syn keyword spin2Reserved ROTXY
syn keyword spin2Reserved POLXY
syn keyword spin2Reserved XYPOL
syn keyword spin2Reserved QSIN
syn keyword spin2Reserved QCOS
syn keyword spin2Reserved MULDIV64
syn keyword spin2Reserved GETRND

" Spin2 Memory Methods
syn keyword spin2Reserved GETREGS
syn keyword spin2Reserved SETREGS
syn keyword spin2Reserved BYTEMOVE
syn keyword spin2Reserved WORDMOVE
syn keyword spin2Reserved LONGMOVE
syn keyword spin2Reserved BYTEFILL
syn keyword spin2Reserved WORDFILL
syn keyword spin2Reserved LONGFILL
syn keyword spin2Reserved BYTESWAP
syn keyword spin2Reserved WORDSWAP
syn keyword spin2Reserved LONGSWAP
syn keyword spin2Reserved BYTECOMP
syn keyword spin2Reserved WORDCOMP
syn keyword spin2Reserved LONGCOMP
syn keyword spin2Reserved FILL
syn keyword spin2Reserved COPY
syn keyword spin2Reserved SWAP
syn keyword spin2Reserved COMP

" Spin2 String Methods
syn keyword spin2Reserved STRSIZE
syn keyword spin2Reserved STRCOMP
syn keyword spin2Reserved STRCOPY
syn keyword spin2Reserved STRING
syn keyword spin2Reserved GETCRC
syn keyword spin2Reserved BYTES
syn keyword spin2Reserved WORDS
syn keyword spin2Reserved LONGS
syn keyword spin2Reserved LSTRING

" Spin2 Index/Value Methods
syn keyword spin2Reserved LOOKUP
syn keyword spin2Reserved LOOKUPZ
syn keyword spin2Reserved LOOKDOWN
syn keyword spin2Reserved LOOKDOWNZ

" Spin2 Special Method Pointers
syn keyword spin2Reserved RECV SEND

" PASM2 Conditionals
syn keyword PASM2Cond IF_ALWAYS
syn keyword PASM2Cond IF_NC_AND_NZ IF_NZ_AND_NC
syn keyword PASM2Cond IF_GT IF_A
syn keyword PASM2Cond IF_00 IF_01 IF_10 IF_11 IF_0X IF_1X IF_X0 IF_X1
syn keyword PASM2Cond IF_NOT_00 IF_NOT_01 IF_NOT_10 IF_NOT_11
syn keyword PASM2Cond IF_NC_AND_Z IF_Z_AND_NC
syn keyword PASM2Cond IF_NC
syn keyword PASM2Cond IF_GE IF_AE
syn keyword PASM2Cond IF_C_AND_NZ IF_NZ_AND_C
syn keyword PASM2Cond IF_NZ
syn keyword PASM2Cond IF_NE
syn keyword PASM2Cond IF_C_NE_Z IF_Z_NE_C
syn keyword PASM2Cond IF_DIFF
syn keyword PASM2Cond IF_NC_OR_NZ IF_NZ_OR_NC
syn keyword PASM2Cond IF_C_AND_Z IF_Z_AND_C
syn keyword PASM2Cond IF_C_EQ_Z IF_Z_EQ_C
syn keyword PASM2Cond IF_SAME
syn keyword PASM2Cond IF_Z
syn keyword PASM2Cond IF_E
syn keyword PASM2Cond IF_NC_OR_Z IF_Z_OR_NC
syn keyword PASM2Cond IF_C IF_LT
syn keyword PASM2Cond IF_B
syn keyword PASM2Cond IF_C_OR_NZ IF_NZ_OR_C
syn keyword PASM2Cond IF_C_OR_Z IF_Z_OR_C
syn keyword PASM2Cond IF_LE IF_BE

syn keyword PASM2Cond IF_0000 IF_0001 IF_0010 IF_0011
syn keyword PASM2Cond IF_0100 IF_0101 IF_0110 IF_0111
syn keyword PASM2Cond IF_1000 IF_1001 IF_1010 IF_1011
syn keyword PASM2Cond IF_1100 IF_1101 IF_1110 IF_1111

syn keyword PASM2Flag WC WZ WCZ
syn keyword PASM2Flag ANDC ANDZ ORC ORZ XORC XORZ

" PASM2 MODC/MODCZ Conditions
syn keyword PASM2Modc _CLR
syn keyword PASM2Modc _NC_AND_NZ _NZ_AND_NC
syn keyword PASM2Modc _GT
syn keyword PASM2Modc _NC_AND_Z _Z_AND_NC
syn keyword PASM2Modc _NC
syn keyword PASM2Modc _GE
syn keyword PASM2Modc _C_AND_NZ _NZ_AND_C
syn keyword PASM2Modc _NZ
syn keyword PASM2Modc _NE
syn keyword PASM2Modc _C_NE_Z _Z_NE_C
syn keyword PASM2Modc _NC_OR_NZ _NZ_OR_NC
syn keyword PASM2Modc _C_AND_Z _Z_AND_C
syn keyword PASM2Modc _C_EQ_Z _Z_EQ_C
syn keyword PASM2Modc _Z
syn keyword PASM2Modc _E
syn keyword PASM2Modc _NC_OR_Z _Z_OR_NC
syn keyword PASM2Modc _C
syn keyword PASM2Modc _LT
syn keyword PASM2Modc _C_OR_NZ _NZ_OR_C
syn keyword PASM2Modc _C_OR_Z _Z_OR_C
syn keyword PASM2Modc _LE
syn keyword PASM2Modc _SET

" Spin2/PASM2 Directives
syn keyword spin2Directives ALIGNL ALIGNW
syn keyword spin2Directives BYTEFIT
syn keyword spin2Directives END
syn keyword spin2Directives FILE
syn keyword spin2Directives FIT
syn keyword spin2Directives ORG ORGF ORGH
syn keyword spin2Directives RES
syn keyword spin2Directives _RET _RET_
syn keyword spin2Directives RET RETA RETB RETI0 RETI1 RETI2 RETI3
syn keyword spin2Directives WORDFIT

" PASM2 Instructions
syn keyword PASM2Inst ADD ADDCT1 ADDCT2 ADDCT3 ADDPIX ADDS ADDSX ADDX
syn keyword PASM2Inst ALLOWI ALTB ALTD ALTGB ALTGN
syn keyword PASM2Inst ALTGW ALTI ALTR ALTS ALTSB ALTSN ALTSW
syn keyword PASM2Inst ANDN AUGD AUGS
syn keyword PASM2Inst ASMCLK
syn keyword PASM2Inst BITC BITH BITL BITNC BITNOT BITNZ BITRND BITZ
syn keyword PASM2Inst BLNPIX BRK
syn keyword PASM2Inst CALLA CALLB CALLD CALLPA CALLPB
syn keyword PASM2Inst CMP CMPM CMPR CMPS CMPSUB CMPSX CMPX
syn keyword PASM2Inst COGBRK CRCBIT CRCNIB
syn keyword PASM2Inst DECMOD
syn keyword PASM2Inst DIRC DIRH DIRL DIRNC DIRNOT DIRNZ DIRRND DIRZ
syn keyword PASM2Inst DJF DJNF DJNZ DJZ
syn keyword PASM2Inst DRVC DRVH DRVL DRVNC DRVNOT DRVNZ DRVRND DRVZ
syn keyword PASM2Inst EXECF
syn keyword PASM2Inst FBLOCK
syn keyword PASM2Inst FGE FGES
syn keyword PASM2Inst FLE FLES FLTC FLTH FLTL FLTNC FLTNOT FLTNZ FLTRND FLTZ
syn keyword PASM2Inst GETBRK GETBYTE GETNIB GETPTR GETQX GETQY GETSCP GETWORD
syn keyword PASM2Inst GETXACC
syn keyword PASM2Inst IJNZ IJZ INCMOD
syn keyword PASM2Inst JATN JCT1 JCT2 JCT3 JFBW JINT
syn keyword PASM2Inst JMP JMPREL
syn keyword PASM2Inst JNATN JNCT1 JNCT2 JNCT3
syn keyword PASM2Inst JNFBW JNINT JNPAT JNQMT
syn keyword PASM2Inst JNSE1 JNSE2 JNSE3 JNSE4 JNXFI JNXMT JNXRL JNXRO
syn keyword PASM2Inst JPAT JQMT
syn keyword PASM2Inst JSE1 JSE2 JSE3 JSE4
syn keyword PASM2Inst JXFI JXMT JXRL JXRO
syn keyword PASM2Inst LOC
syn keyword PASM2Inst MERGEB MERGEW
syn keyword PASM2Inst MIXPIX
syn keyword PASM2Inst MODC MODCZ MODZ
syn keyword PASM2Inst MOV MOVBYTS
syn keyword PASM2Inst MUL MULPIX MULS
syn keyword PASM2Inst MUXC MUXNC MUXNIBS MUXNITS MUXNZ MUXQ MUXZ
syn keyword PASM2Inst NEG NEGC NEGNC NEGNZ NEGZ
syn keyword PASM2Inst NIXINT1 NIXINT2 NIXINT3
syn keyword PASM2Inst NOP
syn keyword PASM2Inst OUTC OUTH OUTL OUTNC OUTNOT OUTNZ OUTRND OUTZ
syn keyword PASM2Inst POLLCT1 POLLCT2 POLLCT3 POLLFBW POLLINT POLLPAT POLLQMT
syn keyword PASM2Inst POLLSE1 POLLSE2 POLLSE3 POLLSE4 POLLXFI POLLXMT POLLXRL
syn keyword PASM2Inst POLLXRO
syn keyword PASM2Inst POP POPA POPB
syn keyword PASM2Inst PUSH PUSHA PUSHB
syn keyword PASM2Inst QDIV QFRAC QMUL QROTATE QSQRT QVECTOR
syn keyword PASM2Inst RCL RCR RCZL RCZR
syn keyword PASM2Inst RDBYTE RDFAST RDLONG RDLUT RDWORD
syn keyword PASM2Inst REP
syn keyword PASM2Inst RESI0 RESI1 RESI2 RESI3
syn keyword PASM2Inst RFBYTE RFLONG RFVAR RFVARS RFWORD
syn keyword PASM2Inst RGBEXP RGBSQZ
syn keyword PASM2Inst ROLBYTE ROLNIB ROLWORD
syn keyword PASM2Inst SAL
syn keyword PASM2Inst SETBYTE SETCFRQ SETCI SETCMOD SETCQ SETCY SETD SETDACS
syn keyword PASM2Inst SETINT1 SETINT2 SETINT3 SETLUTS SETNIB SETPAT SETPIV
syn keyword PASM2Inst SETPIX SETQ SETQ2 SETR SETS SETSCP
syn keyword PASM2Inst SETSE1 SETSE2 SETSE3 SETSE4 SETWORD SETXFRQ
syn keyword PASM2Inst SEUSSF SEUSSR
syn keyword PASM2Inst SHL SHR
syn keyword PASM2Inst SKIP SKIPF
syn keyword PASM2Inst SPLITB SPLITW
syn keyword PASM2Inst STALLI
syn keyword PASM2Inst SUB SUBR SUBS SUBSX SUBX
syn keyword PASM2Inst SUMC SUMNC SUMNZ SUMZ
syn keyword PASM2Inst TEST TESTB TESTBN TESTN TESTP TESTPN
syn keyword PASM2Inst TJF TJNF TJNS TJNZ TJS TJV TJZ
syn keyword PASM2Inst TRGINT1 TRGINT2 TRGINT3
syn keyword PASM2Inst WAITCT1 WAITCT2 WAITCT3 WAITFBW WAITINT WAITPAT
syn keyword PASM2Inst WAITSE1 WAITSE2 WAITSE3 WAITSE4
syn keyword PASM2Inst WAITX WAITXFI WAITXMT WAITXRL WAITXRO
syn keyword PASM2Inst WFBYTE WFLONG WFWORD WMLONG
syn keyword PASM2Inst WRBYTE WRC WRFAST WRLONG WRLUT WRNC WRNZ WRWORD WRZ
syn keyword PASM2Inst XCONT XINIT XORO32 XSTOP XZERO

" PASM2 Flags
syn keyword PASM2Flag WC WZ

" Smart Pin Modes
syn keyword SmartPin P_TRUE_A P_INVERT_A
syn keyword SmartPin P_LOCAL_A P_PLUS1_A P_PLUS2_A P_PLUS3_A P_OUTBIT_A
syn keyword SmartPin P_MINUS3_A P_MINUS2_A P_MINUS1_A
syn keyword SmartPin P_TRUE_B P_INVERT_B
syn keyword SmartPin P_LOCAL_B P_PLUS1_B P_PLUS2_B P_PLUS3_B P_OUTBIT_B
syn keyword SmartPin P_MINUS3_B P_MINUS2_B P_MINUS1_B
syn keyword SmartPin P_PASS_AB P_AND_AB P_OR_AB P_XOR_AB
syn keyword SmartPin P_FILT0_AB P_FILT1_AB P_FILT2_AB P_FILT3_AB
syn keyword SmartPin P_LOGIC_A P_LOGIC_A_FB P_LOGIC_B_FB
syn keyword SmartPin P_SCHMITT_A P_SCHMITT_A_FB P_SCHMITT_B_FB
syn keyword SmartPin P_COMPARE_AB P_COMPARE_AB_FB
syn keyword SmartPin P_ADC_GIO P_ADC_VIO P_ADC_FLOAT
syn keyword SmartPin P_ADC_1X P_ADC_3X P_ADC_10X P_ADC_30X P_ADC_100X
syn keyword SmartPin P_DAC_990R_3V P_DAC_600R_2V P_DAC_124R_3V P_DAC_75R_2V
syn keyword SmartPin P_LEVEL_A P_LEVEL_A_FBN P_LEVEL_B_FBP P_LEVEL_B_FBN
syn keyword SmartPin P_ASYNC_IO P_SYNC_IO
syn keyword SmartPin P_TRUE_IN P_INVERT_IN
syn keyword SmartPin P_TRUE_OUTPUT P_TRUE_OUT P_INVERT_OUTPUT P_INVERT_OUT
syn keyword SmartPin P_HIGH_FAST P_HIGH_1K5 P_HIGH_15K P_HIGH_150K
syn keyword SmartPin P_HIGH_1MA P_HIGH_100UA P_HIGH_10UA P_HIGH_FLOAT
syn keyword SmartPin P_LOW_FAST P_LOW_1K5 P_LOW_15K P_LOW_150K
syn keyword SmartPin P_LOW_1MA P_LOW_100UA P_LOW_10UA P_LOW_FLOAT
syn keyword SmartPin P_TT_00 P_TT_01 P_TT_10 P_TT_11
syn keyword SmartPin P_OE P_CHANNEL P_BITDAC
syn keyword SmartPin P_NORMAL P_REPOSITORY P_DAC_NOISE
syn keyword SmartPin P_DAC_DITHER_RND P_DAC_DITHER_PWM
syn keyword SmartPin P_PULSE P_TRANSITION
syn keyword SmartPin P_NCO_FREQ P_NCO_DUTY
syn keyword SmartPin P_PWM_TRIANGLE P_PWM_SAWTOOTH
syn keyword SmartPin P_PWM_SMPS P_QUADRATURE
syn keyword SmartPin P_REG_UP P_REG_UP_DOWN
syn keyword SmartPin P_COUNT_RISES P_COUNT_HIGHS
syn keyword SmartPin P_STATE_TICKS P_HIGH_TICKS P_EVENTS_TICKS
syn keyword SmartPin P_PERIODS_TICKS P_PERIODS_HIGHS
syn keyword SmartPin P_COUNTER_TICKS P_COUNTER_HIGHS P_COUNTER_PERIODS
syn keyword SmartPin P_ADC P_ADC_EXT P_ADC_SCOPE
syn keyword SmartPin P_USB_PAIR
syn keyword SmartPin P_SYNC_TX P_SYNC_RX
syn keyword SmartPin P_ASYNC_TX P_ASYNC_RX

" Streamer Modes
syn keyword Streamer X_IMM_32X1_LUT X_IMM_16X2_LUT X_IMM_8X4_LUT X_IMM_4X8_LUT
syn keyword Streamer X_IMM_32X1_1DAC1 X_IMM_16X2_2DAC1 X_IMM_16X2_1DAC2
syn keyword Streamer X_IMM_8X4_4DAC1 X_IMM_8X4_2DAC2 X_IMM_8X4_1DAC4
syn keyword Streamer X_IMM_4X8_4DAC2 X_IMM_4X8_2DAC4 X_IMM_4X8_1DAC8
syn keyword Streamer X_IMM_2X16_4DAC4 X_IMM_2X16_2DAC8 X_IMM_1X32_4DAC8
syn keyword Streamer X_RFLONG_32X1_LUT X_RFLONG_16X2_LUT
syn keyword Streamer X_RFLONG_8X4_LUT X_RFLONG_4X8_LUT
syn keyword Streamer X_RFBYTE_1P_1DAC1 X_RFBYTE_2P_2DAC1 X_RFBYTE_2P_1DAC2
syn keyword Streamer X_RFBYTE_4P_4DAC1 X_RFBYTE_4P_2DAC2 X_RFBYTE_4P_1DAC4
syn keyword Streamer X_RFBYTE_8P_4DAC2 X_RFBYTE_8P_2DAC4 X_RFBYTE_8P_1DAC8
syn keyword Streamer X_RFWORD_16P_4DAC4 X_RFWORD_16P_2DAC8 X_RFLONG_32P_4DAC8
syn keyword Streamer X_RFBYTE_LUMA8
syn keyword Streamer X_RFBYTE_RGBI8 X_RFBYTE_RGB8 X_RFWORD_RGB16 X_RFLONG_RGB24
syn keyword Streamer X_1P_1DAC1_WFBYTE X_2P_2DAC1_WFBYTE X_2P_1DAC2_WFBYTE
syn keyword Streamer X_4P_4DAC1_WFBYTE X_4P_2DAC2_WFBYTE X_4P_1DAC4_WFBYTE
syn keyword Streamer X_8P_4DAC2_WFBYTE X_8P_2DAC4_WFBYTE X_8P_1DAC8_WFBYTE
syn keyword Streamer X_16P_4DAC4_WFWORD X_16P_2DAC8_WFWORD X_32P_4DAC8_WFLONG
syn keyword Streamer X_1ADC8_0P_1DAC8_WFBYTE X_1ADC8_8P_2DAC8_WFWORD
syn keyword Streamer X_2ADC8_0P_2DAC8_WFWORD X_2ADC8_16P_4DAC8_WFLONG
syn keyword Streamer X_4ADC8_0P_4DAC8_WFLONG
syn keyword Streamer X_DDS_GOERTZEL_SINC1 X_DDS_GOERTZEL_SINC2
syn keyword Streamer X_DACS_OFF X_DACS_0_0_0_0 X_DACS_X_X_0_0 X_DACS_0_0_X_X
syn keyword Streamer X_DACS_X_X_X_0 X_DACS_X_X_0_X X_DACS_X_0_X_X X_DACS_0_X_X_X
syn keyword Streamer X_DACS_0N0_0N0 X_DACS_X_X_0N0 X_DACS_0N0_X_X X_DACS_1_0_1_0
syn keyword Streamer X_DACS_X_X_1_0 X_DACS_1_0_X_X X_DACS_1N1_0N0 X_DACS_3_2_1_0
syn keyword Streamer X_PINS_OFF X_PINS_ON
syn keyword Streamer X_WRITE_OFF X_WRITE_ON
syn keyword Streamer X_ALT_OFF X_ALT_ON

" Events/Interrupt Sources
syn keyword Events EVENT_INT
syn keyword Events INT_OFF
syn keyword Events EVENT_CT1
syn keyword Events EVENT_CT2
syn keyword Events EVENT_CT3
syn keyword Events EVENT_SE1
syn keyword Events EVENT_SE2
syn keyword Events EVENT_SE3
syn keyword Events EVENT_SE4
syn keyword Events EVENT_PAT
syn keyword Events EVENT_FBW
syn keyword Events EVENT_XMT
syn keyword Events EVENT_XFI
syn keyword Events EVENT_XRO
syn keyword Events EVENT_XRL
syn keyword Events EVENT_ATN
syn keyword Events EVENT_QMT

" Coginit Usage
syn keyword Usage COGEXEC
syn keyword Usage HUBEXEC
syn keyword Usage COGEXEC_NEW
syn keyword Usage HUBEXEC_NEW
syn keyword Usage COGEXEC_NEW_PAIR
syn keyword Usage HUBEXEC_NEW_PAIR

" Cogspin Usage
syn keyword Usage NEWCOG

" Boolean Constants
syn keyword NumBool FALSE
syn keyword NumBool TRUE

" Numeric Constants
syn keyword NumCon NEGX
syn keyword NumCon POSX
syn keyword NumCon PI

" Spin2 Future Use Keywords
syn keyword Future DEV PRECOMPILE ARCHIVE

" Various #'s as defined by GAS ref manual sec 3.6.2.1
" Technically, the first decNumber def is actually octal,
" since the value of 0-7 octal is the same as 0-7 decimal,
" I prefer to map it as decimal:
syn match decNumber		"#\?[0-9][0-9_]*"
syn match hexNumber		"#\?\$[0-9a-fA-F_]\+"
syn match binNumber		"#\?%[01_]\+\>"
syn match quatNumber		"#\?%%[0-3_]\+\>"

" Spin2 Operators (Don't change the order of these definitions)
" Note: I can't get all the single character operators to highlight
"       this is probably due to prior regex definitions/usage. 
syn match spin2Operators	"("
syn match spin2Operators	")"
syn match spin2Operators	'\['
syn match spin2Operators	'\]'
syn match spin2Operators	'\,'
syn match spin2Operators	'='
syn match spin2Operators	'\:'
syn match spin2Operators	'\\'
syn match spin2Operators	'\.'
syn match spin2Operators	'\~'
syn match spin2Operators	'`'
syn match spin2Operators	'!'
syn match spin2Operators	'&'
syn match spin2Operators	'\^'

syn match spin2Operators	'|'
syn match spin2Operators	'*'
syn match spin2Operators	'/'
syn match spin2Operators	'+'
syn match spin2Operators	'-'
syn match spin2Operators	'<'
syn match spin2Operators	'>'
syn match spin2Operators	'?'
syn match spin2Operators	'+/'
syn match spin2Operators	'<='
syn match spin2Operators	'>='
syn match spin2Operators	'=='
syn match spin2Operators	'\.\.'
syn match spin2Operators	'\.\.\.'
syn match spin2Operators	'\~\~'
syn match spin2Operators	'++'
syn match spin2Operators	'--'
syn match spin2Operators	'??'
syn match spin2Operators	'>>'
syn match spin2Operators	'<<'
syn match spin2Operators	'//'
syn match spin2Operators	'#>'
syn match spin2Operators	'<#'
syn match spin2Operators	'+<'
syn match spin2FOperators	'\<\>'
syn match spin2Operators	'+>'
syn match spin2Operators	'!!'
syn match spin2Operators	'&&'
syn match spin2Operators	'\^\^'
syn match spin2Operators	'||'
syn match spin2Operators	'+//'
syn match spin2Operators	'+<='
syn match spin2Operators	'+>='
syn match spin2Operators	'<=>'

syn match spin2FOperators	'<\.'
syn match spin2FOperators	'>\.'
syn match spin2FOperators	'<>\.'
syn match spin2FOperators	'==\.'
syn match spin2FOperators	'<=\.'
syn match spin2FOperators	'>=\.'
syn match spin2FOperators	'+\.'
syn match spin2FOperators	'-\.'
syn match spin2FOperators	'*\.'
syn match spin2FOperators	'/\.'

" Spin2 Pointers
syn match spin2Pointers		'\^@'
syn keyword spin2Pointers	FIELD

" Spin2 Comments/DEBUG/Strings
syn match spin2Comment		"'.*"
syn match spin2Debug		"DEBUG(.*"
syn match spin2DebugCON		"DEBUG_.*"
syn region spin2MLComment start="{" end="}" 
syn region spin2MLDocComment start="{{" end="}}" 
syn region spin2String start="\"" end="\""

syn match PASM2Operators	'\#'
syn match PASM2Operators	'##'

syn match SymbolAddress 	'@'
syn match SymbolAddress 	'@@'

syn case match

" Define the default highlighting.
" For version 5.7 and earlier: only when not done already
" For version 5.8 and later: only when an item doesn't have highlighting yet
if version >= 508 || !exists("did_spin2_syntax_inits")
  if version < 508
    let did_spin2_syntax_inits = 1
    command -nargs=+ HiLink hi link <args>
  else
    command -nargs=+ HiLink hi def link <args>
  endif

  :hi Constant ctermfg=black cterm=bold guifg=#FFFF00
  :hi Function ctermfg=red cterm=bold guifg=#F00000
  :hi Structure ctermfg=blue cterm=bold guifg=#0000F0 guibg=#FFFFFF
  :hi Define ctermfg=green cterm=bold guifg=#00F000
  :hi SpecialChar ctermfg=green cterm=bold guifg=#D0D0D0
  :hi NumBool ctermfg=blue cterm=bold guifg=#F000F0
  :hi NumCon ctermfg=blue cterm=bold guifg=#F000F0
  :hi SymbolAddress ctermfg=blue cterm=bold guifg=#00F070
  :hi Float ctermfg=blue cterm=bold guifg=#00D000
  :hi Pointer ctermfg=blue cterm=bold guifg=#D000D0
  :hi Task ctermfg=blue cterm=bold guifg=#00D0F0
  :hi Future ctermfg=blue cterm=bold guifg=#F0F0F0 guibg=#FFFFFF

  " The default methods for highlighting.  Can be overridden later
  HiLink spin2LocalLabel	Label
  HiLink spin2Comment		Comment
  HiLink spin2MLComment		Comment
  HiLink spin2MLDocComment	Comment
  
  HiLink spin2String		String

  HiLink spin2Block		Constant
  HiLink spin2Downld		PreProc
  HiLink spin2Clock		PreProc
  HiLink spin2PreProc 		PreProc
  HiLink spin2PreCondit 	PreCondit
  HiLink spin2Task		Task
  HiLink spin2Struct		Structure
  HiLink spin2Type		Type
  HiLink spin2HubVar		Type
  HiLink spin2Cond		Conditional
  HiLink PASM2Cond		Conditional
  HiLink PASM2Flag 		Conditional
  HiLink PASM2Modc 		Conditional
  HiLink spin2Flow		Label
  HiLink spin2Loop		Repeat
  HiLink spin2Reserved		Special
  HiLink spin2Debug		Function
  HiLink spin2Reg  		Function
  HiLink spin2DebugCON		Function
  HiLink spin2PASM2Reg		Number
  HiLink spin2Float		Float
  HiLink spin2FOperators	Float
  HiLink spin2Operator		Special
  HiLink spin2Operators		Special
  HiLink spin2Pointers		Pointer
  HiLink PASM2Operators		Special
  HiLink spin2Directives	Structure
  HiLink PASM2Inst		Special
  HiLink PASM2Flag		Special
  HiLink SmartPin		Define
  HiLink Streamer		Define
  HiLink Events			Define
  HiLink Usage			SpecialChar
  HiLink NumBool		Boolean
  HiLink NumCon			Number

  HiLink hexNumber		Number
  HiLink decNumber		Number
  HiLink octNumber		Number
  HiLink binNumber		Number
  HiLink quatNumber		Number

  HiLink spin2Identifier	Identifier

  delcommand HiLink

endif

let b:current_syntax = "spin2"
